@@ -3,17 +3,16 @@ from __future__ import annotations
 import asyncio
 import logging
 from asyncio import Lock, TimerHandle, Transport
-from typing import Optional, Type
+from typing import Optional
 
 import async_timeout
 
 from . import DeviceData
-from .api import COMMANDS_SECURED, QUEUE_TIMEOUT, RT, RoborockClient
+from .api import COMMANDS_SECURED, QUEUE_TIMEOUT, RoborockClient
 from .exceptions import CommandVacuumError, RoborockConnectionException, RoborockException
 from .protocol import MessageParser
 from .roborock_message import RoborockMessage, RoborockMessageProtocol
 from .roborock_typing import RoborockCommand
-from .util import get_running_loop_or_create_one
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -23,7 +22,6 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
         if device_data.host is None:
             raise RoborockException("Host is required")
         super().__init__("abc", device_data)
-        self.loop = get_running_loop_or_create_one()
         self.host = device_data.host
         self._batch_structs: list[RoborockMessage] = []
         self._executing = False
@@ -51,7 +49,7 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
             await self.ping()
         except RoborockException:
             pass
-        self.keep_alive_task = self.loop.call_later(10, lambda: asyncio.create_task(self.keep_alive_func()))
+        self.keep_alive_task = self.event_loop.call_later(10, lambda: asyncio.create_task(self.keep_alive_func()))
 
     async def async_connect(self) -> None:
         should_ping = False
@@ -61,7 +59,7 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
                     self.sync_disconnect()
                     async with async_timeout.timeout(QUEUE_TIMEOUT):
                         _LOGGER.info(f"Connecting to {self.host}")
-                        self.transport, _ = await self.loop.create_connection(  # type: ignore
+                        self.transport, _ = await self.event_loop.create_connection(  # type: ignore
                             lambda: self, self.host, 58867
                         )
                         _LOGGER.info(f"Connected to {self.host}")
@@ -73,7 +71,7 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
             await self.keep_alive_func()
 
     def sync_disconnect(self) -> None:
-        if self.transport and self.loop.is_running():
+        if self.transport and self.event_loop.is_running():
             _LOGGER.debug(f"Disconnecting from {self.host}")
             self.transport.close()
         if self.keep_alive_task:
@@ -86,8 +84,7 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
     def build_roborock_message(self, method: RoborockCommand, params: Optional[list | dict] = None) -> RoborockMessage:
         secured = True if method in COMMANDS_SECURED else False
         request_id, timestamp, payload = self._get_payload(method, params, secured)
-        _LOGGER.debug(f"id={request_id} Requesting method {method} with {params}")
-        request_protocol = 4
+        request_protocol = RoborockMessageProtocol.GENERAL_REQUEST
         return RoborockMessage(
             timestamp=timestamp,
             protocol=request_protocol,
@@ -101,9 +98,7 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
             return await self.send_message(
                 RoborockMessage(
                     protocol=protocol,
-                    payload=None,
                     seq=request_id,
-                    version=b"1.0",
                     random=22,
                 )
             )
@@ -116,47 +111,18 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
         return await self.send_message(
             RoborockMessage(
                 protocol=protocol,
-                payload=None,
                 seq=request_id,
-                version=b"1.0",
                 random=23,
             )
         )
 
-    async def send_command(
+    async def _send_command(
         self,
         method: RoborockCommand,
         params: Optional[list | dict] = None,
-        return_type: Optional[Type[RT]] = None,
     ):
         roborock_message = self.build_roborock_message(method, params)
-        response = (await self.send_message(roborock_message))[0]
-        if return_type:
-            return return_type.from_dict(response)
-        return response
-
-    async def async_local_response(self, roborock_message: RoborockMessage):
-        method = roborock_message.get_method()
-        request_id: int | None
-        if not method or not method.startswith("get"):
-            request_id = roborock_message.seq
-            response_protocol = request_id + 1
-        else:
-            request_id = roborock_message.get_request_id()
-            response_protocol = 4
-        if request_id is None:
-            raise RoborockException(f"Failed build message {roborock_message}")
-        (response, err) = await self._async_response(request_id, response_protocol)
-        self._diagnostic_data[method if method is not None else "unknown"] = {
-            "params": roborock_message.get_params(),
-            "response": response,
-            "error": err,
-        }
-        if err:
-            raise CommandVacuumError("", err) from err
-        if roborock_message.protocol == 4:
-            _LOGGER.debug(f"id={request_id} Response from method {roborock_message.get_method()}: {response}")
-        return response
+        return await self.send_message(roborock_message)
 
     def _send_msg_raw(self, data: bytes):
         try:
@@ -166,26 +132,33 @@ class RoborockLocalClient(RoborockClient, asyncio.Protocol):
         except Exception as e:
             raise RoborockException(e) from e
 
-    async def _send_message(self, roborock_messages: list[RoborockMessage] | RoborockMessage):
-        if isinstance(roborock_messages, RoborockMessage):
-            roborock_messages = [roborock_messages]
+    async def send_message(self, roborock_message: RoborockMessage):
+        await self.validate_connection()
+        method = roborock_message.get_method()
+        params = roborock_message.get_params()
+        request_id: int | None
+        if not method or not method.startswith("get"):
+            request_id = roborock_message.seq
+            response_protocol = request_id + 1
+        else:
+            request_id = roborock_message.get_request_id()
+            response_protocol = RoborockMessageProtocol.GENERAL_REQUEST
+        if request_id is None:
+            raise RoborockException(f"Failed build message {roborock_message}")
         local_key = self.device_info.device.local_key
-        msg = MessageParser.build(roborock_messages, local_key=local_key)
+        msg = MessageParser.build(roborock_message, local_key=local_key)
+        if method:
+            _LOGGER.debug(f"id={request_id} Requesting method {method} with {params}")
         # Send the command to the Roborock device
         self._send_msg_raw(msg)
-
-        responses = await asyncio.gather(
-            *[self.async_local_response(roborock_message) for roborock_message in roborock_messages],
-            return_exceptions=True,
-        )
-        exception = next(
-            (response for response in responses if isinstance(response, BaseException)),
-            None,
-        )
-        if exception:
-            raise exception
-        return responses
-
-    async def send_message(self, roborock_messages: list[RoborockMessage] | RoborockMessage):
-        await self.validate_connection()
-        return await self._send_message(roborock_messages)
+        (response, err) = await self._async_response(request_id, response_protocol)
+        self._diagnostic_data[method if method is not None else "unknown"] = {
+            "params": roborock_message.get_params(),
+            "response": response,
+            "error": err,
+        }
+        if err:
+            raise CommandVacuumError(method, err) from err
+        if roborock_message.protocol == RoborockMessageProtocol.GENERAL_REQUEST:
+            _LOGGER.debug(f"id={request_id} Response from method {roborock_message.get_method()}: {response}")
+        return response
